function [ys] = solve_dae12bv( tspan,y0,nint,params,I_vec,varargin )
% Calls solver for the system of equations
% 
% The function calls onto either dae12bv_mex or dae12bv, depending on whether
% solver is run with mex flag equal to true or not.
% The function is called by run12_BV_disch and run12_BV_ch
% 
% Subject to Creative Commons Attribution 4.0 International Public License
% see license.txt
% (c) Monica Marinescu, 23 Sept 2015, monica.marinescu@imperial.ac.uk

%% Housekeeping

p = inputParser;
errorStr_bool = 'Value must be boolean and scalar';
validationFcn_bool = @(x) assert(islogical(x) && isscalar(x) ,errorStr_bool);
addParameter(p,'mex',true,validationFcn_bool)

parse(p,varargin{:})

check_mex = p.Results.mex;

if nargout>4
    error('Too many output variables requested. See documentation')
end


%% MEX calling part
if check_mex==true
    try
        ys=dae12bv_mex(tspan,y0,nint,params,I_vec);
    catch ME
        if (strcmp(ME.identifier,'MATLAB:UndefinedFunction'))
            warning('Mex solver does not exist. Please wait while it is compiled');
            coder -build solver_dae12
            try
                ys=dae12bv_mex(tspan,y0,nint,params,I_vec);
            catch ME2
                rethrow(ME2)
            end
            return
        end
        rethrow(ME)
        
    end
    return
end

%% If compiler is not used

warning('Using MATLAB solver. Consider using mex solver for speed.')
ys=dae12bv(tspan,y0,nint,params,I_vec);

end

